@@ -1,6 +1,8 @@
 
 import jwt
+import json
 import requests
+import json
 from datetime import datetime
 from enum import Enum
 from passageidentity.helper import extractToken, getAuthTokenFromRequest, fetchPublicKey
@@ -20,6 +22,10 @@ class Passage():
         self.passage_apikey = api_key
         self.auth_strategy = auth_strategy
 
+        # if no app id provided, error
+        if not app_id:
+            raise PassageError("Passage App ID must be provided")
+
         # if the pubkey exists in the cache, use that to avoid making requests
         if app_id in PUBKEY_CACHE.keys():
             self.passage_pubkey = PUBKEY_CACHE[app_id]
@@ -66,18 +72,9 @@ class Passage():
         except Exception as e:
             raise PassageError("Could not fetch user data")
 
-
-
     """
-    Get instance of Passage User
+    Activate Passage User
     """
-    def getUserOld(self, user_id):
-        return Passage.PassageUser(self, user_id)
-
-    """
-    Deactivate Passage User
-    """
-
     def activateUser(self, user_id):
         # if no api key, fail
         if self.passage_apikey == "":
@@ -99,7 +96,6 @@ class Passage():
     """
     Deactivate Passage User
     """
-
     def deactivateUser(self, user_id):
         # if no api key, fail
         if self.passage_apikey == "":
@@ -118,11 +114,33 @@ class Passage():
         except Exception as e:
             raise PassageError("Could not deactivate user")
 
+    """
+    Update Passage User's Attributes
+    """
+    def updateUser(self, user_id, attributes):
+        if self.passage_apikey == "":
+            raise PassageError("No Passage API key provided.")
+        
+        header = {"Authorization": "Bearer " + self.passage_apikey}
+        try:
+            url = "https://api.passage.id/v1/apps/" + self.app_id + "/users/" + user_id  
+            r = requests.patch(url, headers=header, data=json.dumps(attributes))
+            if r.status_code != 200:
+                # get error message
+                attributeKeys = ", ".join(attribute for attribute in attributes.keys())
+                message = r.json()["status"]
+                raise PassageError(f"Failed request to update user attributes ({attributeKeys}): {message}")
+            return PassageUser(user_id, r.json()["user"])
+        except Exception:
+            raise PassageError(f"Could not update user attributes")
+
+
 class PassageUser:
 
     def __init__(self, user_id, fields={}):
         self.id = user_id
         self.email = fields["email"]
+        self.phone = fields["phone"]
         self.active = fields["active"]
         self.email_verified = fields["email_verified"]
 
